@@ -83,16 +83,17 @@ impl<S> AsyncMigrate for Client<S>
 where
     S: AsyncRead + AsyncWrite + Unpin + Send,
 {
-    fn assert_migrations_table_query() -> &'static str {
-        // TODO: also make refinery_schema_history table name consistent across all queries, by using a constant,
-        // and here just use it?
-        "IF NOT EXISTS(SELECT 1 FROM sys.Tables WHERE  Name = N'refinery_schema_history')
+    fn assert_migrations_table_query(migration_table_name: &str) -> String {
+        format!(
+            "IF NOT EXISTS(SELECT 1 FROM sys.Tables WHERE  Name = N'{table_name}')
          BEGIN
-           CREATE TABLE refinery_schema_history(
+           CREATE TABLE {table_name}(
              version INT PRIMARY KEY,
              name VARCHAR(255),
              applied_on VARCHAR(255),
              checksum VARCHAR(255));
-         END"
+         END",
+            table_name = migration_table_name
+        )
     }
 }
