@@ -89,18 +89,20 @@ pub(crate) fn verify_migrations(
 }
 
 pub(crate) const ASSERT_MIGRATIONS_TABLE_QUERY: &str =
-    "CREATE TABLE IF NOT EXISTS refinery_schema_history(
+    "CREATE TABLE IF NOT EXISTS %MIGRATION_TABLE_NAME%(
              version INT4 PRIMARY KEY,
              name VARCHAR(255),
              applied_on VARCHAR(255),
              checksum VARCHAR(255));";
 
 pub(crate) const GET_APPLIED_MIGRATIONS_QUERY: &str = "SELECT version, name, applied_on, checksum \
-    FROM refinery_schema_history ORDER BY version ASC;";
+    FROM %MIGRATION_TABLE_NAME% ORDER BY version ASC;";
 
 pub(crate) const GET_LAST_APPLIED_MIGRATION_QUERY: &str =
     "SELECT version, name, applied_on, checksum
-    FROM refinery_schema_history WHERE version=(SELECT MAX(version) from refinery_schema_history)";
+    FROM %MIGRATION_TABLE_NAME% WHERE version=(SELECT MAX(version) from refinery_schema_history)";
+
+pub(crate) const DEFAULT_MIGRATION_TABLE_NAME: &str = "refinery_schema_history";
 
 #[cfg(test)]
 mod tests {
